use geonames;

drop table if exists geoname;
drop table if exists alternatename;
drop table if exists hierarchy;

# These tables are used by the daily update routines.
drop table if exists updates_geoname;
drop table if exists updates_alternatename;
drop table if exists deletes_geoname;
drop table if exists deletes_alternatename;

CREATE TABLE geoname (
geonameid int PRIMARY KEY,
name varchar(200),
asciiname varchar(200),
alternatenames varchar(4000),
latitude decimal(10,7),
longitude decimal(10,7),
fclass char(1),
fcode varchar(10),
country varchar(2),
cc2 varchar(60),
admin1 varchar(20),
admin2 varchar(80),
admin3 varchar(20),
admin4 varchar(20),
population int,
elevation int,
gtopo30 int,
timezone varchar(40),
moddate date
) CHARACTER SET utf8;


CREATE TABLE alternatename (
alternatenameId int PRIMARY KEY,
geonameid int,
isoLanguage varchar(7),
alternateName varchar(200),
isPreferredName boolean,
isShortName boolean
) CHARACTER SET utf8;

CREATE TABLE hierarchy (
parentId int,
childId int,
type varchar(80)
) CHARACTER SET utf8;

CREATE TABLE `updates_geoname` (
  `geonameid` int(11) NOT NULL,
  `name` varchar(200) CHARACTER SET utf8 DEFAULT NULL,
  `asciiname` varchar(200) CHARACTER SET utf8 DEFAULT NULL,
  `alternatenames` varchar(4000) CHARACTER SET utf8 DEFAULT NULL,
  `latitude` decimal(10,7) DEFAULT NULL,
  `longitude` decimal(10,7) DEFAULT NULL,
  `fclass` char(1) CHARACTER SET utf8 DEFAULT NULL,
  `fcode` varchar(10) CHARACTER SET utf8 DEFAULT NULL,
  `country` varchar(2) CHARACTER SET utf8 DEFAULT NULL,
  `cc2` varchar(60) CHARACTER SET utf8 DEFAULT NULL,
  `admin1` varchar(20) CHARACTER SET utf8 DEFAULT NULL,
  `admin2` varchar(80) CHARACTER SET utf8 DEFAULT NULL,
  `admin3` varchar(20) CHARACTER SET utf8 DEFAULT NULL,
  `admin4` varchar(20) CHARACTER SET utf8 DEFAULT NULL,
  `population` int(11) DEFAULT NULL,
  `elevation` int(11) DEFAULT NULL,
  `gtopo30` int(11) DEFAULT NULL,
  `timezone` varchar(40) CHARACTER SET utf8 DEFAULT NULL,
  `moddate` date DEFAULT NULL,
  PRIMARY KEY (`geonameid`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

CREATE TABLE `updates_alternatename` (
  `alternatenameId` int(11) NOT NULL,
  `geonameid` int(11) DEFAULT NULL,
  `isoLanguage` varchar(7) CHARACTER SET utf8 DEFAULT NULL,
  `alternateName` varchar(200) CHARACTER SET utf8 DEFAULT NULL,
  `isPreferredName` tinyint(1) DEFAULT NULL,
  `isShortName` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`alternatenameId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

CREATE TABLE `deletes_geoname` (
  `geonameid` int(11) NOT NULL DEFAULT '0',
  `name` varchar(200) DEFAULT NULL,
  `comment` varchar(2000) DEFAULT NULL,
  PRIMARY KEY (`geonameid`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

CREATE TABLE `deletes_alternatename` (
  `alternatenameId` int(11) NOT NULL DEFAULT '0',
  `geonameid` int(11) DEFAULT NULL,
  `name` varchar(200) DEFAULT NULL,
  `comment` varchar(2000) DEFAULT NULL,
  PRIMARY KEY (`alternatenameId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;


LOAD DATA LOCAL INFILE 'allCountries.txt' INTO TABLE geoname;

LOAD DATA LOCAL INFILE 'alternateNames.txt' INTO TABLE alternatename;

LOAD DATA LOCAL INFILE 'hierarchy.txt' INTO TABLE hierarchy;


# The pipeline only makes use of the indexes on geoname.name, .population and
# alternatename.alternateName. The others were used in experimentation and
# are convenient when running ad hoc queries; they can easily be built if/when
# needed. They are commented out because it does not seem worth creating them
# by default. The fulltext index in particular is very slow to build.

# An index on asciinames has been added, as we now use that too.(Apr 2010)

create index popInd on geoname(population);
create index nameInd on geoname(name);
create index ascnameInd on geoname(asciiname);
#create index fcodeInd on geoname(fcode);
#create index fclassInd on geoname(fclass);
#create fulltext index altsFulltextInd on geoname(alternatenames);

create index altnameTabInd on alternatename(alternateName);
create index altgeoidInd on alternatename(geonameid);
#create index altprefInd on alternatename(isPreferredName);

create index parentInd on hierarchy(parentId);
create index childInd on hierarchy(childId);
